@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2010  Nokia Corporation and/or its subsidiary(-ies)
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2010  Nokia Corporation and/or its subsidiary(-ies).
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -143,13 +129,6 @@ static int file_exists(char const *filename)
 	return stat(filename, &st) == 0;
 }
 
-static int dir_exists(char const *filename)
-{
-	struct stat st;
-
-	return stat(filename, &st) == 0 && S_ISDIR(st.st_mode);
-}
-
 static int file_write(char const *filename, char const *output)
 {
 	FILE *f;
@@ -600,7 +579,7 @@ static void gpio_power_set_state(enum power_state new_state)
 	self.callback(new_state, self.data);
 }
 
-static void phonet_status_cb(GIsiModem *idx, GIsiPhonetLinkState state,
+static void phonet_status_cb(GIsiModem *idx, enum GIsiPhonetLinkState state,
 				char const *ifname, void *dummy)
 {
 	DBG("Link %s (%u) is %s",
@@ -632,76 +611,15 @@ static void phonet_status_cb(GIsiModem *idx, GIsiPhonetLinkState state,
 
 static int gpio_probe_links(void)
 {
-	char const *gpiodir = "/sys/class/gpio";
 	char const *cmtdir = "/dev/cmt";
-	DIR *gpio;
-	struct dirent *d, entry[1];
 
-	if (file_exists(cmtdir)) {
-		DBG("Using %s", cmtdir);
-		return 0;
-	}
-
-	DBG("Using %s: trying to make links to %s", gpiodir, cmtdir);
-
-	if (!dir_exists(cmtdir)) {
-
-		if (mkdir(cmtdir, 0755) == -1) {
-			DBG("%s: %s", cmtdir, strerror(errno));
-			return -(errno = ENODEV);
-		}
-	}
-
-	gpio = opendir(gpiodir);
-	if (gpio == NULL) {
-		DBG("%s: %s", "gpiodir", strerror(errno));
+	if (!file_exists(cmtdir)) {
+		DBG("%s: %s", cmtdir, strerror(errno));
 		return -(errno = ENODEV);
 	}
 
-	while (readdir_r(gpio, entry, &d) == 0) {
-		char nn[PATH_MAX], name[PATH_MAX], from[PATH_MAX], to[PATH_MAX];
-		FILE *nf;
-		size_t len;
-
-		if (d == NULL)
-			return 0;
-
-		snprintf(nn, sizeof nn, "%s/%s/name", gpiodir, d->d_name);
-
-		nf = fopen(nn, "rb");
-		if (nf == NULL) {
-			DBG("%s: %s", nn, strerror(errno));
-			continue;
-		}
-
-		len = fread(name, sizeof name, 1, nf);
-
-		if (ferror(nf)) {
-			DBG("read from %s: %s", nn, strerror(errno));
-			fclose(nf);
-			continue;
-		}
-
-		fclose(nf);
-
-		if (len < 4)
-			continue;
-
-		name[--len] = '\0';
-
-		if (strncmp(name, "cmt_", 4))
-			continue;
-
-		snprintf(from, sizeof from, "%s/%s", gpiodir, d->d_name);
-		snprintf(to, sizeof to, "%s/%s", cmtdir, name);
-
-		if (symlink(from, to) == -1)
-			DBG("%s: %s", to, strerror(errno));
-	}
-
-	DBG("%s: %s", "/sys/class/gpio", strerror(errno));
-
-	return -(errno = ENODEV);
+	DBG("Using %s", cmtdir);
+	return 0;
 }
 
 
