@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1745,10 +1731,12 @@ static void gprs_netreg_update(struct ofono_gprs *gprs)
 	if (gprs->netreg_status < 0)
 		return;
 
-	attach = gprs->netreg_status == NETWORK_REGISTRATION_STATUS_REGISTERED;
+	attach = (gprs->netreg_status == NETWORK_REGISTRATION_STATUS_REGISTERED) ||
+		(gprs->netreg_status == NETWORK_REGISTRATION_STATUS_REGISTERED_SMS_EUTRAN);
 
 	attach = attach || (gprs->roaming_allowed &&
-		gprs->netreg_status == NETWORK_REGISTRATION_STATUS_ROAMING);
+		((gprs->netreg_status == NETWORK_REGISTRATION_STATUS_ROAMING) ||
+		(gprs->netreg_status == NETWORK_REGISTRATION_STATUS_ROAMING_SMS_EUTRAN)));
 
 	attach = attach && gprs->powered;
 
@@ -2820,6 +2808,10 @@ static void gprs_context_remove(struct ofono_atom *atom)
 	g_free(gc);
 }
 
+static void ofono_gprs_context_register(struct ofono_gprs_context *gc)
+{
+}
+
 OFONO_DEFINE_ATOM_CREATE(gprs_context, OFONO_ATOM_TYPE_GPRS_CONTEXT, {
 	atom->type = OFONO_GPRS_CONTEXT_TYPE_ANY;
 })
@@ -3024,9 +3016,6 @@ static void gprs_unregister(struct ofono_atom *atom)
 
 	free_contexts(gprs);
 
-	l_uintset_free(gprs->used_cids);
-	gprs->used_cids = NULL;
-
 	if (gprs->netreg_watch) {
 		if (gprs->status_watch) {
 			__ofono_netreg_remove_status_watch(gprs->netreg,
@@ -3065,6 +3054,9 @@ static void gprs_remove(struct ofono_atom *atom)
 	if (gprs->suspend_timeout)
 		g_source_remove(gprs->suspend_timeout);
 
+	l_uintset_free(gprs->used_cids);
+	gprs->used_cids = NULL;
+
 	l_uintset_free(gprs->used_pids);
 	gprs->used_pids = NULL;
 
